@@ -175,6 +175,28 @@ class AmocrmRunner:
         )
         api_loader.auth(code_auth=code_auth)
 
+    def get_response_objects(self, params={}):
+        """
+        Get response from amocrm url
+        :return: json objects
+        """
+        if self.api_version == 4:
+            from amocrm.api.api_loader_amocrm_v4 import AmocrmApiLoader as ApiLoader
+        elif self.api_version == 2:
+            from amocrm.api.api_loader_amocrm_v2 import AmocrmApiLoader as ApiLoader
+
+        args_api = {"amocrm_api_url": self.amocrm_api_url}
+        api_loader = ApiLoader(
+            self.entity,
+            self.s3_client,
+            args_api,
+            date_modified_from=self.date_modified_from,
+            batch_api=self.batch_api,
+            is_oauth2=self.is_oauth2
+        )
+        api_loader.auth()
+        return api_loader.oath_client.get_response_objects(self.amocrm_api_url, params)
+
     def extract(self):
         """
         1. step to run. Extract from amocrm.api
